(function() {
  var changeFileExtension, colors, cp, dirWatcher, echoUsageAndExit, path, runCommand, util;
  colors = require('colors');
  cp = require('child_process');
  dirWatcher = require('dir-watcher');
  path = require('path');
  util = require('util');
  changeFileExtension = function(filePath, oldExtension, newExtension) {
    if (path.extname(filePath) !== oldExtension) {
      throw 'changeFileExtension Error: Path ' + filePath + ' does not have the extension ' + oldExtension + '.';
    }
    return path.resolve(path.dirname(filePath), path.basename(filePath, oldExtension) + newExtension);
  };
  runCommand = function(cmd, args, finishedCallback) {
    var p;
    p = cp.spawn(cmd, args);
    p.stdout.on('data', function(data) {
      return process.stdout.write(data);
    });
    p.stderr.on('data', function(data) {
      return process.stderr.write(data);
    });
    return p.on('exit', function(exitCode) {
      var exitString;
      exitString = cmd + ' process exited with code ' + exitCode;
      if (exitCode !== 0) {
        util.log(exitString.red);
      } else {
        util.log(exitString.green);
      }
      if (finishedCallback != null) {
        return finishedCallback(exitCode);
      }
    });
  };
  echoUsageAndExit = function() {
    console.warn('Usage: php-autotest <srcDirectoryName> <testDirectoryName>\nDefaults: srcDirectoryName = "src", testDirectoryName = "test"');
    return process.exit(-1);
  };
  exports.start = function() {
    var cwd, runTestFile, srcDirName, srcWatcher, testDirName, testWatcher;
    srcDirName = process.argv[2] != null ? process.argv[2] : 'src';
    testDirName = process.argv[3] != null ? process.argv[3] : 'test';
    if (!path.existsSync(srcDirName)) {
      console.warn("Error: " + srcDirName + " subdirectory does not exist.\n");
      echoUsageAndExit();
    }
    if (!path.existsSync(testDirName)) {
      console.warn("Error: " + testDirName + " subdirectory does not exist.\n");
      echoUsageAndExit();
    }
    runTestFile = function(relativeTestPath, exists) {
      if (exists) {
        util.log('Running test file '.yellow + relativeTestPath.yellow.bold);
        return runCommand('phpunit', [relativeTestPath]);
      } else {
        return util.log(('Test file ' + relativeTestPath + " doesn't exist.").red);
      }
    };
    cwd = process.cwd();
    dirWatcher.setup(true);
    util.log('Watching...');
    srcWatcher = dirWatcher.create(function(entry) {
      var testFile;
      if (path.extname(entry) === '.php') {
        testFile = dirWatcher.getMirrorPath(cwd, entry, srcDirName, 'test');
        testFile = changeFileExtension(testFile, '.php', 'Test.php');
        return path.exists(testFile, function(exists) {
          var relativeTestPath;
          relativeTestPath = dirWatcher.getRelativePath(cwd, testFile);
          return runTestFile(relativeTestPath, exists);
        });
      }
    });
    srcWatcher.watchDirectoryTreeSync(srcDirName);
    testWatcher = dirWatcher.create(function(entry) {
      var relativeTestPath;
      if (path.extname(entry) === '.php') {
        relativeTestPath = dirWatcher.getRelativePath(cwd, entry);
        return runTestFile(relativeTestPath, true);
      }
    });
    return testWatcher.watchDirectoryTreeSync(testDirName);
  };
}).call(this);
